pub struct EvolutionEngine { /* private fields */ }Expand description
Self-tuning evolution engine that adjusts decay and recall parameters based on observed system behaviour.
Implementations
Sourceimpl EvolutionEngine
impl EvolutionEngine
pub fn new() -> Self
Sourcepub fn get_decay_defaults(&self, store_type: StoreType) -> StoreDecayDefaults
pub fn get_decay_defaults(&self, store_type: StoreType) -> StoreDecayDefaults
Get current (possibly adjusted) decay parameters for a store type.
Sourcepub fn observe_decay_tick(&self, store: StoreType, fidelity_scores: &[f64])
pub fn observe_decay_tick(&self, store: StoreType, fidelity_scores: &[f64])
Observe fidelity scores from a decay tick for a specific store.
Sourcepub fn observe_recall(&self, store: StoreType, hit_rate: f64)
pub fn observe_recall(&self, store: StoreType, hit_rate: f64)
Observe recall hit rate for a specific store. hit_rate: fraction of recall results that had relevance > 0 (0.0-1.0).
Sourcepub fn get_metrics(&self) -> EvolutionMetrics
pub fn get_metrics(&self) -> EvolutionMetrics
Get current evolution metrics.